/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021–2022 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

function changePreset() {
	if (document.getElementById('selPreset').value === 'wigm') {
		document.getElementById('selQuotaCriterion').value = 'gt';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = false;
		document.getElementById('chkRoundVotes').checked = false;
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'wig';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'scottish') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '5';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = false;
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '5';
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'per_ballot';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'wig';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'meek87') {
		document.getElementById('selQuotaCriterion').value = 'gt';
		document.getElementById('selQuota').value = 'droop_exact';
		document.getElementById('selQuotaMode').value = 'dynamic_by_total';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = false;
		document.getElementById('chkMeekNZExclusion').checked = false;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = false;
		document.getElementById('chkRoundVotes').checked = false;
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		//document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('txtMeekSurplusTolerance').value = '0.001%';
		//document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'meek';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'meek06') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'dynamic_by_total';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('chkMeekNZExclusion').checked = false;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '12';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '9';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '9';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '9';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '9';
		//document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('txtMeekSurplusTolerance').value = '0.0001';
		//document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'meek';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'forwards,random';
	} else if (document.getElementById('selPreset').value === 'meeknz') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'dynamic_by_total';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('chkMeekNZExclusion').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '12';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '9';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '9';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '9';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '9';
		//document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('txtMeekSurplusTolerance').value = '0.0001';
		//document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'meek';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'forwards,random';
	} else if (document.getElementById('selPreset').value === 'senate') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false; // Senate "bulk exclusion" does not permit quota to be exceeded
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '0';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '0';
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_order';
		document.getElementById('selMethod').value = 'uig';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'by_value';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'wa') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '0';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '0';
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'per_ballot';
		document.getElementById('selSurplus').value = 'by_order';
		document.getElementById('selMethod').value = 'wig';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'by_source';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'act') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '6';
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_order';
		document.getElementById('selMethod').value = 'eg';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'by_value';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'nswlg') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '0';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '0';
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'by_parcel';
		document.getElementById('selSurplus').value = 'by_order';
		document.getElementById('selMethod').value = 'wig';
		document.getElementById('selPapers').value = 'subtract_nontransferable';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'minneapolis') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = true;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = false;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '4';
		document.getElementById('txtPPDP').value = '4';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = false;
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '4';
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'wig';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'random';
	} else if (document.getElementById('selPreset').value === 'cambridge') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('selSample').value = 'cincinnati';
		document.getElementById('chkSamplePerBallot').checked = true;
		document.getElementById('txtMinThreshold').value = '49';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '0';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selMethod').value = 'hare';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'dail') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('selSample').value = 'stratify';
		document.getElementById('chkSamplePerBallot').checked = false;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'rational';
		document.getElementById('txtPPDP').value = '0';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_order';
		document.getElementById('selMethod').value = 'hare';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'single_stage';
		document.getElementById('selTies').value = 'forwards,random';
	} else if (document.getElementById('selPreset').value === 'wright') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = true;
		document.getElementById('chkDeferSurpluses').checked = false;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '0';
		document.getElementById('chkRoundVotes').checked = false;
		document.getElementById('chkRoundSFs').checked = false;
		document.getElementById('chkRoundValues').checked = false;
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'wig';
		document.getElementById('selPapers').value = 'both';
		document.getElementById('selExclusion').value = 'wright';
		document.getElementById('selTies').value = 'random';
	} else if (document.getElementById('selPreset').value === 'prsa77') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '6';
		document.getElementById('txtPPDP').value = '3';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '3';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '3';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '3';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '3';
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_order';
		document.getElementById('selMethod').value = 'eg';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'parcels_by_order';
		document.getElementById('selTies').value = 'backwards,random';
	} else if (document.getElementById('selPreset').value === 'ers97') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop_exact';
		document.getElementById('selQuotaMode').value = 'ers97';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = true;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '2';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '2';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '2';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '2';
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'eg';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'by_value';
		document.getElementById('selTies').value = 'forwards,random';
	} else if (document.getElementById('selPreset').value === 'ers76') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop_exact';
		document.getElementById('selQuotaMode').value = 'ers76';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = true;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '2';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '2';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '2';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '2';
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'eg';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'by_value';
		document.getElementById('selTies').value = 'forwards,random';
	} else if (document.getElementById('selPreset').value === 'ers73') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop_exact';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = true;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '2';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '2';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '2';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '2';
		document.getElementById('selSumTransfers').value = 'single_step';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'eg';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'by_value';
		document.getElementById('selTies').value = 'forwards,random';
	} else if (document.getElementById('selPreset').value === 'cofe') {
		document.getElementById('selQuotaCriterion').value = 'geq';
		document.getElementById('selQuota').value = 'droop';
		document.getElementById('selQuotaMode').value = 'static';
		document.getElementById('chkBulkElection').checked = true;
		document.getElementById('chkBulkExclusion').checked = false;
		document.getElementById('chkDeferSurpluses').checked = true;
		document.getElementById('chkImmediateElect').checked = true;
		document.getElementById('txtMinThreshold').value = '0';
		document.getElementById('selNumbers').value = 'fixed';
		document.getElementById('txtDP').value = '5';
		document.getElementById('txtPPDP').value = '2';
		document.getElementById('chkRoundQuota').checked = true;
		document.getElementById('txtRoundQuota').value = '2';
		document.getElementById('chkRoundVotes').checked = true;
		document.getElementById('txtRoundVotes').value = '2';
		document.getElementById('chkRoundSFs').checked = true;
		document.getElementById('txtRoundSFs').value = '2';
		document.getElementById('chkRoundValues').checked = true;
		document.getElementById('txtRoundValues').value = '2';
		document.getElementById('selSumTransfers').value = 'per_ballot';
		document.getElementById('selSurplus').value = 'by_size';
		document.getElementById('selMethod').value = 'eg';
		document.getElementById('selPapers').value = 'transferable';
		document.getElementById('selExclusion').value = 'by_value';
		document.getElementById('selTies').value = 'forwards,random';
	}
}
