/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

#![allow(clippy::needless_return)]

use opentally::cli;

use clap::Parser;

/// Open-source election vote counting
#[derive(Parser)]
#[clap(name="OpenTally", version=opentally::VERSION)]
struct Opts {
	#[clap(subcommand)]
	command: Command,
}

#[allow(clippy::large_enum_variant)]
#[derive(Parser)]
enum Command {
	Convert(cli::convert::SubcmdOptions),
	Stv(cli::stv::SubcmdOptions),
}

fn main() {
	match main_() {
		Ok(_) => {}
		Err(code) => {
			std::process::exit(code);
		}
	}
}

fn main_() -> Result<(), i32> {
	// Read arguments
	let opts: Opts = Opts::parse();
	
	return match opts.command {
		Command::Convert(cmd_opts) => cli::convert::main(cmd_opts),
		Command::Stv(cmd_opts) => cli::stv::main(cmd_opts),
	};
}
