/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use crate::election::Election;
use crate::numbers::Number;

use rkyv::{Deserialize, Infallible, archived_root};

use std::fs;
use std::path::Path;

/// Parse the given BIN file
pub fn parse_path<P: AsRef<Path>, N: Number>(path: P) -> Election<N> {
	let content = fs::read(path).expect("IO Error");
	return parse_bytes(&content);
}

/// Parse the given BIN file
pub fn parse_bytes<N: Number>(content: &[u8]) -> Election<N> {
	let archived = unsafe {
		archived_root::<Election<N>>(content)
	};
	return archived.deserialize(&mut Infallible).unwrap();
}
