/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use crate::election::Election;
use crate::numbers::Number;

use rkyv::ser::{Serializer, serializers::AllocSerializer};

use std::io::{BufWriter, Write};

/// Write the [Election] into BIN format
pub fn write<W: Write, N: Number>(election: Election<N>, output: W) {
	// Serialize data using rkyv
	let mut serializer = AllocSerializer::<256>::default();
	serializer.serialize_value(&election).unwrap();
	let buffer = serializer.into_serializer().into_inner();
	
	// Write output
	let mut output = BufWriter::new(output);
	output.write_all(&buffer).expect("IO Error");
}
