/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use crate::utils;

use opentally::numbers::Rational;
use opentally::stv;

#[test]
fn cambridge_cc03_rational() {
	let stv_opts = stv::STVOptionsBuilder::default()
		.round_quota(Some(0))
		.quota_criterion(stv::QuotaCriterion::GreaterOrEqual)
		.surplus(stv::SurplusMethod::Hare)
		.transferable_only(true)
		.sample(stv::SampleMethod::Cincinnati)
		.sample_per_ballot(true)
		.early_bulk_elect(false)
		.min_threshold("49".to_string())
		.build().unwrap();
	
	assert_eq!(stv_opts.describe::<Rational>(), "--round-quota 0 --quota-criterion geq --surplus hare --transferable-only --sample cincinnati --sample-per-ballot --no-early-bulk-elect --min-threshold 49");
	
	utils::read_validate_election::<Rational>("tests/data/CambCC2003.csv", "tests/data/CambCC2003.blt", stv_opts, None, &["exhausted"]);
}
