/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021–2022 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use crate::utils;

use opentally::numbers::Rational;
use opentally::stv;

#[test]
fn ers97_coe_rational() {
	let stv_opts = stv::STVOptionsBuilder::default()
		.round_surplus_fractions(Some(2))
		.round_values(Some(2))
		.round_votes(Some(2))
		.round_quota(Some(2))
		.round_subtransfers(stv::RoundSubtransfersMode::PerBallot)
		.quota_criterion(stv::QuotaCriterion::GreaterOrEqual)
		.surplus(stv::SurplusMethod::EG)
		.transferable_only(true)
		.exclusion(stv::ExclusionMethod::ByValue)
		.defer_surpluses(true)
		.build().unwrap();
	
	assert_eq!(stv_opts.describe::<Rational>(), "--round-surplus-fractions 2 --round-values 2 --round-votes 2 --round-quota 2 --round-subtransfers per_ballot --quota-criterion geq --surplus eg --transferable-only --exclusion by_value --defer-surpluses");
	
	utils::read_validate_election::<Rational>("tests/data/ers97_coe.csv", "tests/data/ers97.blt", stv_opts, None, &["nt"]);
}
