/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use crate::utils;

use opentally::numbers::Rational;
use opentally::stv;

#[test]
fn minneapolis_boe09_rational() {
	let stv_opts = stv::STVOptionsBuilder::default()
		.round_surplus_fractions(Some(4))
		.round_quota(Some(0))
		.quota_criterion(stv::QuotaCriterion::GreaterOrEqual)
		//.early_bulk_elect(true)
		.bulk_exclude(true)
		.defer_surpluses(true)
		.immediate_elect(false)
		.build().unwrap();
	
	assert_eq!(stv_opts.describe::<Rational>(), "--round-surplus-fractions 4 --round-quota 0 --quota-criterion geq --bulk-exclude --defer-surpluses --no-immediate-elect");
	
	utils::read_validate_election::<Rational>("tests/data/Mppls-2009-BOE-full.csv", "tests/data/Mppls-2009-BOE-full.blt", stv_opts, Some(4), &[]);
}

#[test]
fn minneapolis_pal13_rational() {
	let stv_opts = stv::STVOptionsBuilder::default()
		.round_surplus_fractions(Some(4))
		.round_quota(Some(0))
		.quota_criterion(stv::QuotaCriterion::GreaterOrEqual)
		//.early_bulk_elect(true)
		.bulk_exclude(true)
		.defer_surpluses(true)
		.immediate_elect(false)
		.build().unwrap();
	
	assert_eq!(stv_opts.describe::<Rational>(), "--round-surplus-fractions 4 --round-quota 0 --quota-criterion geq --bulk-exclude --defer-surpluses --no-immediate-elect");
	
	utils::read_validate_election::<Rational>("tests/data/2013-Park-At-Large-CVR.csv", "tests/data/2013-Park-At-Large-CVR.blt", stv_opts, Some(4), &[]);
}
