/*  OpenTally: Open-source election vote counting
 *  Copyright © 2021 Lee Yingtong Li (RunasSudo)
 *
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU Affero General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Affero General Public License for more details.
 *
 *  You should have received a copy of the GNU Affero General Public License
 *  along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

use crate::utils;

use opentally::numbers::Rational;
use opentally::stv;

#[test]
fn prsa1_rational() {
	let stv_opts = stv::STVOptionsBuilder::default()
		.round_surplus_fractions(Some(3))
		.round_values(Some(3))
		.round_votes(Some(3))
		.round_quota(Some(3))
		.quota_criterion(stv::QuotaCriterion::GreaterOrEqual)
		.surplus(stv::SurplusMethod::EG)
		.surplus_order(stv::SurplusOrder::ByOrder)
		.transferable_only(true)
		.exclusion(stv::ExclusionMethod::ParcelsByOrder)
		.early_bulk_elect(false)
		.build().unwrap();
	
	assert_eq!(stv_opts.describe::<Rational>(), "--round-surplus-fractions 3 --round-values 3 --round-votes 3 --round-quota 3 --quota-criterion geq --surplus eg --surplus-order by_order --transferable-only --exclusion parcels_by_order --no-early-bulk-elect");
	
	utils::read_validate_election::<Rational>("tests/data/prsa1.csv", "tests/data/prsa1.blt", stv_opts, None, &["exhausted", "lbf"]);
}
